// This file may be redistributed and modified only under the terms of
// the GNU General Public License (See COPYING for details).
// Copyright (C) 2002 Alistair Riddoch

#ifndef RULESETS_AREA_H
#define RULESETS_AREA_H

#include "Thing.h"

typedef Thing Area_parent;

/// \brief This is the base class for area based geomap features.
///
/// On the atlas side, it inherits from feature, but feature does not have
/// any added attributes or functionality over thing. This is not yet fully
/// implemented.
class Area : public Area_parent {
  protected:
    IdList m_segments;

  public:

    explicit Area(const std::string & id, long intId);
    virtual ~Area();
};

#endif // RULESETS_AREA_H
